@@ -24,7 +24,8 @@ class Authorizable:
         realm = self.get_realm()
         return (
             self.get_resource_qualname(),
-            realm.get_realm_authorizations(subject, self)
+            realm.get_realm_authorizations(subject, self)\
+            if realm else set()
         )
 
     def get_realm(self):
